# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winrt._winrt_windows_media_core import (
    MseTimeRange,
    TimedTextDouble,
    TimedTextPadding,
    TimedTextPoint,
    TimedTextSize,
    AudioStreamDescriptor,
    AudioTrack,
    AudioTrackOpenFailedEventArgs,
    AudioTrackSupportInfo,
    ChapterCue,
    CodecInfo,
    CodecQuery,
    CodecSubtypes,
    DataCue,
    FaceDetectedEventArgs,
    FaceDetectionEffect,
    FaceDetectionEffectDefinition,
    FaceDetectionEffectFrame,
    HighDynamicRangeControl,
    HighDynamicRangeOutput,
    ImageCue,
    InitializeMediaStreamSourceRequestedEventArgs,
    LowLightFusion,
    LowLightFusionResult,
    MediaBinder,
    MediaBindingEventArgs,
    MediaCueEventArgs,
    MediaSource,
    MediaSourceAppServiceConnection,
    MediaSourceError,
    MediaSourceOpenOperationCompletedEventArgs,
    MediaSourceStateChangedEventArgs,
    MediaStreamSample,
    MediaStreamSamplePropertySet,
    MediaStreamSampleProtectionProperties,
    MediaStreamSource,
    MediaStreamSourceClosedEventArgs,
    MediaStreamSourceClosedRequest,
    MediaStreamSourceSampleRenderedEventArgs,
    MediaStreamSourceSampleRequest,
    MediaStreamSourceSampleRequestDeferral,
    MediaStreamSourceSampleRequestedEventArgs,
    MediaStreamSourceStartingEventArgs,
    MediaStreamSourceStartingRequest,
    MediaStreamSourceStartingRequestDeferral,
    MediaStreamSourceSwitchStreamsRequest,
    MediaStreamSourceSwitchStreamsRequestDeferral,
    MediaStreamSourceSwitchStreamsRequestedEventArgs,
    MseSourceBuffer,
    MseSourceBufferList,
    MseStreamSource,
    SceneAnalysisEffect,
    SceneAnalysisEffectDefinition,
    SceneAnalysisEffectFrame,
    SceneAnalyzedEventArgs,
    SpeechCue,
    TimedMetadataStreamDescriptor,
    TimedMetadataTrack,
    TimedMetadataTrackError,
    TimedMetadataTrackFailedEventArgs,
    TimedTextBouten,
    TimedTextCue,
    TimedTextLine,
    TimedTextRegion,
    TimedTextRuby,
    TimedTextSource,
    TimedTextSourceResolveResultEventArgs,
    TimedTextStyle,
    TimedTextSubformat,
    VideoStabilizationEffect,
    VideoStabilizationEffectDefinition,
    VideoStabilizationEffectEnabledChangedEventArgs,
    VideoStreamDescriptor,
    VideoTrack,
    VideoTrackOpenFailedEventArgs,
    VideoTrackSupportInfo,
    _IMediaCue,
    IMediaCue,
    _IMediaSource,
    IMediaSource,
    _IMediaStreamDescriptor,
    IMediaStreamDescriptor,
    _IMediaStreamDescriptor2,
    IMediaStreamDescriptor2,
    _IMediaTrack,
    IMediaTrack,
    _ISingleSelectMediaTrackList,
    ISingleSelectMediaTrackList,
    _ITimedMetadataTrackProvider,
    ITimedMetadataTrackProvider,
)

__all__ = [
    "AudioDecoderDegradation",
    "AudioDecoderDegradationReason",
    "CodecCategory",
    "CodecKind",
    "FaceDetectionMode",
    "MediaDecoderStatus",
    "MediaSourceState",
    "MediaSourceStatus",
    "MediaStreamSourceClosedReason",
    "MediaStreamSourceErrorStatus",
    "MediaTrackKind",
    "MseAppendMode",
    "MseEndOfStreamStatus",
    "MseReadyState",
    "SceneAnalysisRecommendation",
    "TimedMetadataKind",
    "TimedMetadataTrackErrorCode",
    "TimedTextBoutenPosition",
    "TimedTextBoutenType",
    "TimedTextDisplayAlignment",
    "TimedTextFlowDirection",
    "TimedTextFontStyle",
    "TimedTextLineAlignment",
    "TimedTextRubyAlign",
    "TimedTextRubyPosition",
    "TimedTextRubyReserve",
    "TimedTextScrollMode",
    "TimedTextUnit",
    "TimedTextWeight",
    "TimedTextWrapping",
    "TimedTextWritingMode",
    "VideoStabilizationEffectEnabledChangedReason",
    "MseTimeRange",
    "TimedTextDouble",
    "TimedTextPadding",
    "TimedTextPoint",
    "TimedTextSize",
    "AudioStreamDescriptor",
    "AudioTrack",
    "AudioTrackOpenFailedEventArgs",
    "AudioTrackSupportInfo",
    "ChapterCue",
    "CodecInfo",
    "CodecQuery",
    "CodecSubtypes",
    "DataCue",
    "FaceDetectedEventArgs",
    "FaceDetectionEffect",
    "FaceDetectionEffectDefinition",
    "FaceDetectionEffectFrame",
    "HighDynamicRangeControl",
    "HighDynamicRangeOutput",
    "ImageCue",
    "InitializeMediaStreamSourceRequestedEventArgs",
    "LowLightFusion",
    "LowLightFusionResult",
    "MediaBinder",
    "MediaBindingEventArgs",
    "MediaCueEventArgs",
    "MediaSource",
    "MediaSourceAppServiceConnection",
    "MediaSourceError",
    "MediaSourceOpenOperationCompletedEventArgs",
    "MediaSourceStateChangedEventArgs",
    "MediaStreamSample",
    "MediaStreamSamplePropertySet",
    "MediaStreamSampleProtectionProperties",
    "MediaStreamSource",
    "MediaStreamSourceClosedEventArgs",
    "MediaStreamSourceClosedRequest",
    "MediaStreamSourceSampleRenderedEventArgs",
    "MediaStreamSourceSampleRequest",
    "MediaStreamSourceSampleRequestDeferral",
    "MediaStreamSourceSampleRequestedEventArgs",
    "MediaStreamSourceStartingEventArgs",
    "MediaStreamSourceStartingRequest",
    "MediaStreamSourceStartingRequestDeferral",
    "MediaStreamSourceSwitchStreamsRequest",
    "MediaStreamSourceSwitchStreamsRequestDeferral",
    "MediaStreamSourceSwitchStreamsRequestedEventArgs",
    "MseSourceBuffer",
    "MseSourceBufferList",
    "MseStreamSource",
    "SceneAnalysisEffect",
    "SceneAnalysisEffectDefinition",
    "SceneAnalysisEffectFrame",
    "SceneAnalyzedEventArgs",
    "SpeechCue",
    "TimedMetadataStreamDescriptor",
    "TimedMetadataTrack",
    "TimedMetadataTrackError",
    "TimedMetadataTrackFailedEventArgs",
    "TimedTextBouten",
    "TimedTextCue",
    "TimedTextLine",
    "TimedTextRegion",
    "TimedTextRuby",
    "TimedTextSource",
    "TimedTextSourceResolveResultEventArgs",
    "TimedTextStyle",
    "TimedTextSubformat",
    "VideoStabilizationEffect",
    "VideoStabilizationEffectDefinition",
    "VideoStabilizationEffectEnabledChangedEventArgs",
    "VideoStreamDescriptor",
    "VideoTrack",
    "VideoTrackOpenFailedEventArgs",
    "VideoTrackSupportInfo",
    "IMediaCue",
    "IMediaSource",
    "IMediaStreamDescriptor",
    "IMediaStreamDescriptor2",
    "IMediaTrack",
    "ISingleSelectMediaTrackList",
    "ITimedMetadataTrackProvider",
]

class AudioDecoderDegradation(enum.IntEnum):
    NONE = 0
    DOWNMIX_TO2_CHANNELS = 1
    DOWNMIX_TO6_CHANNELS = 2
    DOWNMIX_TO8_CHANNELS = 3

class AudioDecoderDegradationReason(enum.IntEnum):
    NONE = 0
    LICENSING_REQUIREMENT = 1
    SPATIAL_AUDIO_NOT_SUPPORTED = 2

class CodecCategory(enum.IntEnum):
    ENCODER = 0
    DECODER = 1

class CodecKind(enum.IntEnum):
    AUDIO = 0
    VIDEO = 1

class FaceDetectionMode(enum.IntEnum):
    HIGH_PERFORMANCE = 0
    BALANCED = 1
    HIGH_QUALITY = 2

class MediaDecoderStatus(enum.IntEnum):
    FULLY_SUPPORTED = 0
    UNSUPPORTED_SUBTYPE = 1
    UNSUPPORTED_ENCODER_PROPERTIES = 2
    DEGRADED = 3

class MediaSourceState(enum.IntEnum):
    INITIAL = 0
    OPENING = 1
    OPENED = 2
    FAILED = 3
    CLOSED = 4

class MediaSourceStatus(enum.IntEnum):
    FULLY_SUPPORTED = 0
    UNKNOWN = 1

class MediaStreamSourceClosedReason(enum.IntEnum):
    DONE = 0
    UNKNOWN_ERROR = 1
    APP_REPORTED_ERROR = 2
    UNSUPPORTED_PROTECTION_SYSTEM = 3
    PROTECTION_SYSTEM_FAILURE = 4
    UNSUPPORTED_ENCODING_FORMAT = 5
    MISSING_SAMPLE_REQUESTED_EVENT_HANDLER = 6

class MediaStreamSourceErrorStatus(enum.IntEnum):
    OTHER = 0
    OUT_OF_MEMORY = 1
    FAILED_TO_OPEN_FILE = 2
    FAILED_TO_CONNECT_TO_SERVER = 3
    CONNECTION_TO_SERVER_LOST = 4
    UNSPECIFIED_NETWORK_ERROR = 5
    DECODE_ERROR = 6
    UNSUPPORTED_MEDIA_FORMAT = 7

class MediaTrackKind(enum.IntEnum):
    AUDIO = 0
    VIDEO = 1
    TIMED_METADATA = 2

class MseAppendMode(enum.IntEnum):
    SEGMENTS = 0
    SEQUENCE = 1

class MseEndOfStreamStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    DECODE_ERROR = 2
    UNKNOWN_ERROR = 3

class MseReadyState(enum.IntEnum):
    CLOSED = 0
    OPEN = 1
    ENDED = 2

class SceneAnalysisRecommendation(enum.IntEnum):
    STANDARD = 0
    HDR = 1
    LOW_LIGHT = 2

class TimedMetadataKind(enum.IntEnum):
    CAPTION = 0
    CHAPTER = 1
    CUSTOM = 2
    DATA = 3
    DESCRIPTION = 4
    SUBTITLE = 5
    IMAGE_SUBTITLE = 6
    SPEECH = 7

class TimedMetadataTrackErrorCode(enum.IntEnum):
    NONE = 0
    DATA_FORMAT_ERROR = 1
    NETWORK_ERROR = 2
    INTERNAL_ERROR = 3

class TimedTextBoutenPosition(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    OUTSIDE = 2

class TimedTextBoutenType(enum.IntEnum):
    NONE = 0
    AUTO = 1
    FILLED_CIRCLE = 2
    OPEN_CIRCLE = 3
    FILLED_DOT = 4
    OPEN_DOT = 5
    FILLED_SESAME = 6
    OPEN_SESAME = 7

class TimedTextDisplayAlignment(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    CENTER = 2

class TimedTextFlowDirection(enum.IntEnum):
    LEFT_TO_RIGHT = 0
    RIGHT_TO_LEFT = 1

class TimedTextFontStyle(enum.IntEnum):
    NORMAL = 0
    OBLIQUE = 1
    ITALIC = 2

class TimedTextLineAlignment(enum.IntEnum):
    START = 0
    END = 1
    CENTER = 2

class TimedTextRubyAlign(enum.IntEnum):
    CENTER = 0
    START = 1
    END = 2
    SPACE_AROUND = 3
    SPACE_BETWEEN = 4
    WITH_BASE = 5

class TimedTextRubyPosition(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    OUTSIDE = 2

class TimedTextRubyReserve(enum.IntEnum):
    NONE = 0
    BEFORE = 1
    AFTER = 2
    BOTH = 3
    OUTSIDE = 4

class TimedTextScrollMode(enum.IntEnum):
    POPON = 0
    ROLLUP = 1

class TimedTextUnit(enum.IntEnum):
    PIXELS = 0
    PERCENTAGE = 1

class TimedTextWeight(enum.IntEnum):
    NORMAL = 400
    BOLD = 700

class TimedTextWrapping(enum.IntEnum):
    NO_WRAP = 0
    WRAP = 1

class TimedTextWritingMode(enum.IntEnum):
    LEFT_RIGHT_TOP_BOTTOM = 0
    RIGHT_LEFT_TOP_BOTTOM = 1
    TOP_BOTTOM_RIGHT_LEFT = 2
    TOP_BOTTOM_LEFT_RIGHT = 3
    LEFT_RIGHT = 4
    RIGHT_LEFT = 5
    TOP_BOTTOM = 6

class VideoStabilizationEffectEnabledChangedReason(enum.IntEnum):
    PROGRAMMATIC = 0
    PIXEL_RATE_TOO_HIGH = 1
    RUNNING_SLOWLY = 2

winrt.system._mixin_mutable_mapping(MediaStreamSamplePropertySet)
